%global _target_platform %{_vendor}-%{_target_os}

%bcond_with check
%bcond_with optional_components

Summary:        C-Library for JPEG 2000
Name:           openjpeg2
Version:        2.5.0
Release:        4%{?dist}
License:        BSD and MIT
URL:            https://github.com/uclouvain/openjpeg
Source0:        https://github.com/uclouvain/openjpeg/archive/v%{version}/openjpeg-%{version}.tar.gz
%if %{with check}
# git clone git@github.com:uclouvain/openjpeg-data.git
Source1:        data.tar.xz
%endif

Patch3000:      openjpeg2_opj2.patch
Patch3001:      heap-buffer-overflow.patch


BuildRequires:  cmake make doxygen gcc gcc-c++
BuildRequires:  zlib-devel libpng-devel libtiff-devel lcms2-devel zlib-devel
BuildRequires:  jbigkit-devel libjpeg-turbo-devel libwebp-devel libzstd-devel
%if %{with optional_components}
BuildRequires:  java-devel xerces-j2
%endif

%description
The OpenJPEG library is an open-source JPEG 2000 library developed in order to
promote the use of JPEG 2000.

This package contains
* JPEG 2000 codec compliant with the Part 1 of the standard (Class-1 Profile-1
  compliance).
* JP2 (JPEG 2000 standard Part 2 - Handling of JP2 boxes and extended multiple
  component transforms for multispectral and hyperspectral imagery)

%package devel
Summary:        Development files for OpenJPEG 2
Requires:       %{name} = %{version}-%{release}
Requires:       %{name}-tools = %{version}-%{release}

%description devel
The %{name}-devel package contains libraries and header files for developing
applications that use OpenJPEG 2.

%package tools
Summary:        OpenJPEG 2 command line tools
Requires:       %{name} = %{version}-%{release}

%description tools
Command line tools for JPEG 2000 file manipulation, using OpenJPEG2:
 * opj2_compress
 * opj2_decompress
 * opj2_dump

%if %{with optional_components}
%package mj2
Summary:        OpenJPEG2 MJ2 module
Requires:       %{name} = %{version}-%{release}

%description mj2
The OpenJPEG library is an open-source JPEG 2000 library developed in order to
promote the use of JPEG 2000.

This package contains the MJ2 module (JPEG 2000 standard Part 3)

%package mj2-devel
Summary:        Development files for OpenJPEG2 MJ2 module
Requires:       %{name}-devel = %{version}-%{release}
Requires:       %{name}-mj2 = %{version}-%{release}

%description mj2-devel
Development files for OpenJPEG2 MJ2 module

%package mj2-tools
Summary:        OpenJPEG2 MJ2 module command line tools
Requires:       %{name}-mj2 = %{version}-%{release}

%description mj2-tools
OpenJPEG2 MJ2 module command line tools

%package jpwl
Summary:        OpenJPEG2 JPWL module
Requires:       %{name} = %{version}-%{release}

%description jpwl
The OpenJPEG library is an open-source JPEG 2000 library developed in order to
promote the use of JPEG 2000.

This package contains the JPWL (JPEG 2000 standard Part 11 - Jpeg 2000 Wireless)

%package jpwl-devel
Summary:        Development files for OpenJPEG2 JPWL module
Requires:       %{name}-devel = %{version}-%{release}
Requires:       %{name}-jpwl = %{version}-%{release}

%description jpwl-devel
Development files for OpenJPEG2 JPWL module

%package jpwl-tools
Summary:        OpenJPEG2 JPWL module command line tools
Requires:       %{name}-jpwl = %{version}-%{release}

%description jpwl-tools
OpenJPEG2 JPWL module command line tools

%package jpip
Summary:        OpenJPEG2 JPIP module
Requires:       %{name} = %{version}-%{release}

%description jpip
The OpenJPEG library is an open-source JPEG 2000 library developed in order to
promote the use of JPEG 2000.

This package contains the JPWL (JPEG 2000 standard Part 9 - Jpeg 2000 Interactive Protocol)

%package jpip-devel
Summary:        Development files for OpenJPEG2 JPIP module
Requires:       %{name}-devel = %{version}-%{release}
Requires:       %{name}-jpwl = %{version}-%{release}

%description jpip-devel
Development files for OpenJPEG2 JPIP module

%package jpip-tools
Summary:        OpenJPEG2 JPIP module command line tools
Requires:       %{name}-jpip = %{version}-%{release}
Requires:       jpackage-utils java

%description jpip-tools
OpenJPEG2 JPIP module command line tools

%package jp3d
Summary:        OpenJPEG2 JP3D module
Requires:       %{name} = %{version}-%{release}

%description jp3d
The OpenJPEG library is an open-source JPEG 2000 library developed in order to
promote the use of JPEG 2000.

This package contains the JP3D (JPEG 2000 standard Part 10 - Jpeg 2000 3D)

%package jp3d-devel
Summary:        Development files for OpenJPEG2 JP3D module
Requires:       %{name}-devel = %{version}-%{release}
Requires:       %{name}-jp3d = %{version}-%{release}

%description jp3d-devel
Development files for OpenJPEG2 JP3D module

%package jp3d-tools
Summary:        OpenJPEG2 JP3D module command line tools
Requires:       %{name}-jp3d = %{version}-%{release}

%description jp3d-tools
OpenJPEG2 JP3D module command line tools
%endif

%prep
%autosetup -p1 -n openjpeg-%{version} %{?with_check:-a 1}
find thirdparty/ -mindepth 1 -maxdepth 1 -type d -exec rm -rf {} \;


%build
%cmake -DCMAKE_BUILD_TYPE=RelWithDebInfo \
    -DOPENJPEG_INSTALL_LIB_DIR=%{_lib} \
%if %{with optional_components}
    -DBUILD_MJ2=ON -DBUILD_JPWL=ON -DBUILD_JPIP=ON -DBUILD_JP3D=ON \
%endif
    -DBUILD_DOC=ON \
    -DBUILD_STATIC_LIBS=OFF \
    -DBUILD_SHARED_LIBS=ON \
%if %{with check}
    -DBUILD_TESTING:BOOL=ON -DOPJ_DATA_ROOT=$PWD/../data
%endif

%cmake_build

%install
%cmake_install

mv %{buildroot}%{_mandir}/man1/opj_compress.1 %{buildroot}%{_mandir}/man1/opj2_compress.1
mv %{buildroot}%{_mandir}/man1/opj_decompress.1 %{buildroot}%{_mandir}/man1/opj2_decompress.1
mv %{buildroot}%{_mandir}/man1/opj_dump.1 %{buildroot}%{_mandir}/man1/opj2_dump.1
rm -rf %{buildroot}%{_datadir}/doc/

%if %{with optional_components}
mkdir -p %{buildroot}%{_javadir}
mv %{buildroot}%{_datadir}/opj_jpip_viewer.jar %{buildroot}%{_javadir}/opj2_jpip_viewer.jar
cat > %{buildroot}%{_bindir}/opj2_jpip_viewer <<EOF
java -jar %{_javadir}/opj2_jpip_viewer.jar "$@"
EOF
chmod +x %{buildroot}%{_bindir}/opj2_jpip_viewer
%endif

%check
%if %{with check}
%ctest
%endif

%files
%license LICENSE
%doc AUTHORS.md NEWS.md README.md THANKS.md
%{_libdir}/libopenjp2.so.*
%{_mandir}/man3/libopenjp2.3*

%files devel
%doc %{__cmake_builddir}/doc/html
%dir %{_includedir}/openjpeg-2.5/
%{_includedir}/openjpeg-2.5/openjpeg.h
%{_includedir}/openjpeg-2.5/opj_config.h
%{_includedir}/openjpeg-2.5/opj_stdint.h
%{_libdir}/libopenjp2.so
%{_libdir}/openjpeg-2.5/
%{_libdir}/pkgconfig/libopenjp2.pc

%files tools
%{_bindir}/opj2_compress
%{_bindir}/opj2_decompress
%{_bindir}/opj2_dump
%{_mandir}/man1/opj2_compress.1*
%{_mandir}/man1/opj2_decompress.1*
%{_mandir}/man1/opj2_dump.1*

%if %{with optional_components}
%files mj2
%{_libdir}/libopenmj2.so.*

%files mj2-devel
%{_libdir}/libopenmj2.so

%files mj2-tools
%{_bindir}/opj2_mj2*

%files jpwl
%{_libdir}/libopenjpwl.so.*

%files jpwl-devel
%{_libdir}/libopenjpwl.so
%{_libdir}/pkgconfig/libopenjpwl.pc

%files jpwl-tools
%{_bindir}/opj2_jpwl*

%files jpip
%{_libdir}/libopenjpip.so.*

%files jpip-devel
%{_libdir}/libopenjpip.so
%{_libdir}/pkgconfig/libopenjpip.pc

%files jpip-tools
%{_bindir}/opj2_jpip*
%{_bindir}/opj2_dec_server
%{_javadir}/opj2_jpip_viewer.jar

%files jp3d
%{_libdir}/libopenjp3d.so.*

%files jp3d-devel
%{_includedir}/openjpeg-2.0/openjp3d.h
%{_libdir}/libopenjp3d.so
%{_libdir}/pkgconfig/libopenjp3d.pc

%files jp3d-tools
%{_bindir}/opj2_jp3d*
%endif

%changelog
* Thu Sep 26 2024 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 2.5.0-4
- Rebuilt for clarifying the packages requirement in BaseOS and AppStream

* Fri Aug 16 2024 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 2.5.0-3
- Rebuilt for loongarch release

* Fri Sep 08 2023 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 2.5.0-2
- Rebuilt for OpenCloudOS Stream 23.09

* Thu Aug 17 2023 kianli <kianli@tencent.com> - 2.5.0-1
- Upgrade to 2.5.0

* Wed Aug 02 2023 kianli <kianli@tencent.com> - 2.4.0-4
- Rebuilt for libtiff 4.5.1

* Fri Apr 28 2023 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 2.4.0-3
- Rebuilt for OpenCloudOS Stream 23.05

* Fri Mar 31 2023 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 2.4.0-2
- Rebuilt for OpenCloudOS Stream 23

* Wed Nov 23 2022 Xiaojie Chen <jackxjchen@tencent.com> - 2.4.0-1
- Initial build
